ContentUriTrigger class

Execute when a content URI changes (Android only).

Inheritance

Constructors

ContentUriTrigger({required Uri uri, bool triggerForDescendants = false})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerForDescendants → bool
If true, triggers for changes in descendant URIs as well.
final
uri → Uri
Content URI to observe.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert to map for platform channel.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override