ExactTrigger class

Execute at an exact time.

Inheritance

Constructors

ExactTrigger(DateTime scheduledTime)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledTime DateTime
The exact time to execute.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to map for platform channel.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override