FileOperation enum

File system operations.

Inheritance
Available extensions

Values

copy → const FileOperation
const FileOperation('copy')
move → const FileOperation
const FileOperation('move')
delete → const FileOperation
const FileOperation('delete')
mkdir → const FileOperation
const FileOperation('mkdir')
list → const FileOperation
const FileOperation('list')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FileOperation>
A constant List of the values in this enum, in order of their declaration.