FileSystemCopyWorker class final

File system worker configuration for copy operation.

Inheritance
Annotations

Constructors

FileSystemCopyWorker({required String sourcePath, required String destinationPath, bool overwrite = false, bool recursive = true})
const

Properties

destinationPath String
final
hashCode int
The hash code for this object.
no setterinherited
overwrite bool
final
recursive bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcePath String
final
workerClassName String
Get the worker class name for native side.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to map for platform channel.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited