RemoteTriggerRule class

A rule for matching and executing a remote trigger.

When a remote message arrives, the plugin looks for a field in the payload named payloadKey. If the value of that field matches a key in workerMappings, the corresponding worker is enqueued.

Use {{key}} syntax in worker parameters to substitute values from the remote payload.

Annotations

Constructors

RemoteTriggerRule({required String payloadKey, required Map<String, Worker> workerMappings, String? secretKey})
Create a rule for matching remote triggers.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payloadKey String
The key in the remote message payload to look for.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String?
Optional secret key for HMAC SHA-256 signature verification.
final
workerMappings Map<String, Worker>
Map of payload values to their corresponding worker templates.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to a map for the platform channel.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited