TaskTrigger class sealed

Defines when a task should be executed.

Implementers

Constructors

TaskTrigger.batteryLow()
Execute when battery IS low (Android only).
const
factory
TaskTrigger.batteryOkay()
Execute when battery is NOT low (Android only).
const
factory
TaskTrigger.contentUri({required Uri uri, bool triggerForDescendants})
Execute when a content URI changes (Android only).
const
factory
TaskTrigger.deviceIdle()
Execute when device is idle (Android only).
const
factory
TaskTrigger.exact(DateTime scheduledTime)
Execute at an exact time (alarm-style).
const
factory
TaskTrigger.oneTime([Duration initialDelay])
Execute once after an optional delay.
const
factory
TaskTrigger.periodic(Duration interval, {Duration? flexInterval, Duration? initialDelay, bool runImmediately})
Execute periodically at a fixed interval.
const
factory
TaskTrigger.storageLow()
Execute when storage is low (Android only).
const
factory
TaskTrigger.windowed({required Duration earliest, required Duration latest})
Execute within a time window.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to map for platform channel.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited