Worker class abstract

Base class for all worker configurations.

All built-in workers (HttpDownloadWorker, FileCompressWorker, etc.) extend this class. Custom native workers use CustomNativeWorker.

Implementers
Annotations

Constructors

Worker()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workerClassName String
Get the worker class name for native side.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to map for platform channel.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited