FakeChainRecord class

A full record of a chain that was enqueued via FakeWorkManager.beginWith.

Constructors

FakeChainRecord({required TaskRequest firstTask, required List<List<TaskRequest>> steps})
const

Properties

allTasks List<TaskRequest>
Flat list of all tasks across all steps, in order.
no setter
firstTask TaskRequest
The task passed to FakeWorkManager.beginWith.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<List<TaskRequest>>
All steps of the built chain (each step is a list of parallel tasks). Mirrors TaskChainBuilder.steps.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited