CryptoHashWorker class final
Crypto worker configuration for file hashing.
Computes cryptographic hash of a file or string.
Constructors
- CryptoHashWorker.file({required String? filePath, HashAlgorithm algorithm = HashAlgorithm.sha256})
-
const
- CryptoHashWorker.string({required String? data, HashAlgorithm algorithm = HashAlgorithm.sha256})
-
const
Properties
- algorithm → HashAlgorithm
-
Hash algorithm to use.
final
- data → String?
-
String data to hash (null if hashing file).
final
- filePath → String?
-
Path to file to hash (null if hashing string data).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workerClassName → String
-
Get the worker class name for native side.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Convert to map for platform channel.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited