CustomNativeWorker class final
Custom native worker configuration.
Allows users to register and use their own native worker implementations without modifying the plugin source code.
Constructors
-
CustomNativeWorker({required String className, Map<
String, dynamic> ? input})
Properties
- className → String
-
The native worker class name (must be registered on native side).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, dynamic> ? -
Optional input data (will be JSON encoded).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workerClassName → String
-
Get the worker class name for native side.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Convert to map for platform channel.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited