GraphExecution class
Handle returned by NativeWorkManager.enqueueGraph.
Exposes a result future that resolves when the entire graph finishes (all nodes complete or any node fails).
Constructors
-
GraphExecution.internal(String graphId, Future<
GraphResult> result) -
Internal constructor for testing.
factory
Properties
- graphId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
result
→ Future<
GraphResult> -
Resolves when all graph nodes have finished executing.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited