TaskNode class
A node in a TaskGraph.
Each node represents one background task. Nodes can have zero or more dependencies — a node does not execute until all its dependencies complete successfully.
- Annotations
Constructors
Properties
- constraints → Constraints
-
Optional scheduling constraints for this node.
final
-
dependsOn
→ List<
String> -
IDs of nodes that must complete before this node runs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique ID for this task within the graph.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worker → Worker
-
The worker to execute.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert to map for platform channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited