TaskTrigger class sealed
Defines when a task should be executed.
Constructors
- TaskTrigger.batteryLow()
-
Execute when battery IS low (Android only).
constfactory
- TaskTrigger.batteryOkay()
-
Execute when battery is NOT low (Android only).
constfactory
- TaskTrigger.contentUri({required Uri uri, bool triggerForDescendants})
-
Execute when a content URI changes (Android only).
constfactory
- TaskTrigger.deviceIdle()
-
Execute when device is idle (Android only).
constfactory
- TaskTrigger.exact(DateTime scheduledTime)
-
Execute at an exact time (alarm-style).
constfactory
- TaskTrigger.oneTime([Duration initialDelay])
-
Execute once after an optional delay.
constfactory
- TaskTrigger.periodic(Duration interval, {Duration? flexInterval, Duration? initialDelay, bool runImmediately})
-
Execute periodically at a fixed interval.
constfactory
- TaskTrigger.storageLow()
-
Execute when storage is low (Android only).
constfactory
- TaskTrigger.windowed({required Duration earliest, required Duration latest})
-
Execute within a time window.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert to map for platform channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited