UploadFileOutcome class

Per-file outcome inside ParallelUploadResult.files.

Annotations

Constructors

UploadFileOutcome({required String fileName, required String filePath, required int fileSize, required bool success, int? statusCode, String? responseBody, String? error})
const

Properties

error String?
final
fileName String
final
filePath String
final
fileSize int
final
hashCode int
The hash code for this object.
no setterinherited
responseBody String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited