EnqueueCall class
A single recorded FakeWorkManager.enqueue invocation.
Constructors
- EnqueueCall({required String taskId, required TaskTrigger trigger, required Worker worker, required Constraints constraints, required ExistingTaskPolicy existingPolicy, String? tag})
-
const
Properties
- constraints → Constraints
-
final
- existingPolicy → ExistingTaskPolicy
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
- taskId → String
-
final
- trigger → TaskTrigger
-
final
- worker → Worker
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override